@@ -109,7 +109,8 @@ class data(object):
 
         if status_code != 200:
             print('HTTP Request failed - status %(status_code)s' % locals())
-            sys.exit(0)
+            raise ConnectionError(
+                'HTTP Request failed - status %(status_code)s. URL: %(url)s' % locals())
 
         # CONVERT THE RESPONSE TO CSV LIST OF DICTIONARIES
         self.csvDicts = csv.DictReader(
@@ -472,14 +473,17 @@ class data(object):
 
         # SET THE MASTER ID FLAG FOR ALL NEW TRANSIENTS IN THE TRANSIENTBUCKET
         newTransientBucketIds = (",").join(newTransientBucketIds)
-        sqlQuery = """update transientBucket set masterIDFlag = 1 where primaryKeyId in (select * from (
-SELECT 
-    primaryKeyId
-FROM
-    transientBucket
-WHERE
-    transientBucketId IN (%(newTransientBucketIds)s)
-GROUP BY transientBucketId) as a )""" % locals()
+        sqlQuery = """UPDATE transientBucket t
+                            JOIN
+                        (SELECT 
+                            transientBucketId, MIN(primaryKeyId) AS minpk
+                        FROM
+                            transientBucket
+                        WHERE
+                            transientBucketId IN (%(newTransientBucketIds)s)
+                        GROUP BY transientBucketId) tmin ON t.primaryKeyId = tmin.minpk 
+                    SET 
+                        masterIDFlag = 1;""" % locals()
         writequery(
             log=self.log,
             sqlQuery=sqlQuery,
@@ -522,7 +526,7 @@ GROUP BY transientBucketId) as a )""" % locals()
 
         sqlQueries = [
             "insert into sherlock_classifications (transient_object_id) select distinct transientBucketId from transientBucketSummaries ON DUPLICATE KEY UPDATE  transient_object_id = transientBucketId;",
-            "CALL update_transient_akas(); "
+            "CALL update_transient_akas(1); "
         ]
 
         for sqlQuery in sqlQueries:
